@@ -20,3 +20,6 @@ class Bundle:
         self.vertical_promo_image = data.get("verticalPromoImage")
         self.asset_path = data.get("assetPath")
         self.raw_data = data
+
+    def __str__(self):
+        return str(self.raw_data)
