@@ -18,3 +18,6 @@ class Currency:
         self.large_icon = data.get("largeIcon")
         self.asset_path = data.get("assetPath")
         self.raw_data = data
+
+    def __str__(self):
+        return str(self.raw_data)
